#!/bin/sh
mkdir ~/laz-temp/indy
mv compiler/indy-10.2.0.3.tar.gz ~/laz-temp/indy/indy-10.2.0.3.tar.gz
cd ~/laz-temp/indy
tar -zxvf ./indy-10.2.0.3.tar.gz
